
package interfazgrafica7;

import javax.swing.JCheckBox;
import javax.swing.JLabel;
import javax.swing.JRadioButton;
import javax.swing.JToggleButton;

public class Componentes {

      private GestorEventos gestorEventos;
      private AreaDibujo areaDibujo;
      private JLabel jLabelVisualizaPosicionRaton;  
      private JToggleButton jToggleButtonLineas; 
      private JToggleButton jToggleButtonRectangulos;
      private JToggleButton jToggleButtonOvalos;   
      private JRadioButton jRadioButtonLineas; 
      private JRadioButton jRadioButtonRectangulos;
      private JRadioButton jRadioButtonOvalos;  
      private JCheckBox jCheckBoxLineas; 
      private JCheckBox jCheckBoxRectangulos;
      private JCheckBox jCheckBoxOvalos;              
      private byte tipoFigura = 1;
    
    public byte getTipoFigura() {
        return tipoFigura;
    }

    public void setTipoFigura(byte tipoFigura) {
        this.tipoFigura = tipoFigura;
    }

    public GestorEventos getGestorEventos() {
        return gestorEventos;
    }

    public void setGestorEventos(GestorEventos gestorEventos) {
        this.gestorEventos = gestorEventos;
    }      
      
    public JLabel getjLabelVisualizaPosicionRaton() {
        return jLabelVisualizaPosicionRaton;
    }

    public void setjLabelVisualizaPosicionRaton(JLabel jLabelVisualizaPosicionRaton) {
        this.jLabelVisualizaPosicionRaton = jLabelVisualizaPosicionRaton;
    }

    public AreaDibujo getAreaDibujo() {
        return areaDibujo;
    }

    public void setAreaDibujo(AreaDibujo areaDibujo) {
        this.areaDibujo = areaDibujo;
    } 

    public JToggleButton getjToggleButtonLineas() {
        return jToggleButtonLineas;
    }

    public void setjToggleButtonLineas(JToggleButton jToggleButtonLineas) {
        this.jToggleButtonLineas = jToggleButtonLineas;
    }

    public JToggleButton getjToggleButtonRectangulos() {
        return jToggleButtonRectangulos;
    }

    public void setjToggleButtonRectangulos(JToggleButton jToggleButtonRectangulos) {
        this.jToggleButtonRectangulos = jToggleButtonRectangulos;
    }

    public JToggleButton getjToggleButtonOvalos() {
        return jToggleButtonOvalos;
    }

    public void setjToggleButtonOvalos(JToggleButton jToggleButtonOvalos) {
        this.jToggleButtonOvalos = jToggleButtonOvalos;
    }

    public JRadioButton getjRadioButtonLineas() {
        return jRadioButtonLineas;
    }

    public void setjRadioButtonLineas(JRadioButton jRadioButtonLineas) {
        this.jRadioButtonLineas = jRadioButtonLineas;
    }

    public JRadioButton getjRadioButtonRectangulos() {
        return jRadioButtonRectangulos;
    }

    public void setjRadioButtonRectangulos(JRadioButton jRadioButtonRectangulos) {
        this.jRadioButtonRectangulos = jRadioButtonRectangulos;
    }

    public JRadioButton getjRadioButtonOvalos() {
        return jRadioButtonOvalos;
    }

    public void setjRadioButtonOvalos(JRadioButton jRadioButtonOvalos) {
        this.jRadioButtonOvalos = jRadioButtonOvalos;
    }

    public JCheckBox getjCheckBoxLineas() {
        return jCheckBoxLineas;
    }

    public void setjCheckBoxLineas(JCheckBox jCheckBoxLineas) {
        this.jCheckBoxLineas = jCheckBoxLineas;
    }

    public JCheckBox getjCheckBoxRectangulos() {
        return jCheckBoxRectangulos;
    }

    public void setjCheckBoxRectangulos(JCheckBox jCheckBoxRectangulos) {
        this.jCheckBoxRectangulos = jCheckBoxRectangulos;
    }

    public JCheckBox getjCheckBoxOvalos() {
        return jCheckBoxOvalos;
    }

    public void setjCheckBoxOvalos(JCheckBox jCheckBoxOvalos) {
        this.jCheckBoxOvalos = jCheckBoxOvalos;
    }
}
