
package interfazgrafica7;

import javax.swing.ButtonGroup;
import javax.swing.JPanel;
import javax.swing.JCheckBox;

public class PanelJCheckBox extends JPanel {

      private Componentes componentes;
      
    public PanelJCheckBox(Componentes componentes) {
        this.componentes = componentes;
        ubicarComponentes();        
    }
    
    private void ubicarComponentes() {
        
        setLayout(null);
        
        componentes.setjCheckBoxLineas(new JCheckBox("Línea", true));
        componentes.getjCheckBoxLineas().setBounds(255, 45, 100, 40);
        add(componentes.getjCheckBoxLineas());
        componentes.getjCheckBoxLineas().addItemListener(componentes.getGestorEventos());
        
        componentes.setjCheckBoxRectangulos(new JCheckBox("Rectángulo", false));
        componentes.getjCheckBoxRectangulos().setBounds(255, 105, 100, 40);
        add(componentes.getjCheckBoxRectangulos());
        componentes.getjCheckBoxRectangulos().addItemListener(componentes.getGestorEventos());

        componentes.setjCheckBoxOvalos(new JCheckBox("Óvalo", false));
        componentes.getjCheckBoxOvalos().setBounds(255, 165, 100, 40);
        add(componentes.getjCheckBoxOvalos());
        componentes.getjCheckBoxOvalos().addItemListener(componentes.getGestorEventos());   
        
        ButtonGroup buttonGroup = new ButtonGroup();
        buttonGroup.add(componentes.getjCheckBoxLineas());
        buttonGroup.add(componentes.getjCheckBoxRectangulos());
        buttonGroup.add(componentes.getjCheckBoxOvalos());
    }        
}
